function [sampleParameters,optimalParameters] = sampleParameterSets(allParameters,sampelingMethodIdx,nSampleParameters)

% sampleParameters  = datasample(allParameters(:,2:end-1),1000,1,'Replace',false);
nParameters = size(allParameters,2)-2;
[~,sortedIndex]=sort(allParameters(:,1)); %sort the fvalues and get the sort index.

sampleParameters = nan(nSampleParameters,nParameters);

switch sampelingMethodIdx

    %% Method 1 - sample close to optimal
    case 1

        sampleParameters = allParameters(sortedIndex(1:min(nSampleParameters,size(allParameters,1))),2:end-1); %get the parameters that correspond to the N lowest fvalues
        %% Method 2 - sample close to threshold
    case 2
        sampleParameters = allParameters(sortedIndex(end-min(nSampleParameters,size(allParameters,1)-1):end),2:end-1); %get the parameters that correspont to the 10% highest fvalues

        %% Method 3 - random sampling
    case 3
        randomSampleIdx = datasample([1:size(allParameters,1)].',nSampleParameters-1,'Replace',false); % get a random idex values without replacement.
        sampleParameters = allParameters(randomSampleIdx,2:end-1);

        [~,optimalIndex] = min(allParameters(:,1));
        optimalParameters = allParameters(optimalIndex,2:end-1);

        sampleParameters = [optimalParameters;sampleParameters]; % add the optimalparameters at the top of the sample parameters matrix

    case 4
        %% Sample parameters, method 4 - Uniformly 
        % sort column i take N uniformly distributed values. Repeat for all i.
        N = round(nSampleParameters./nParameters);

        rowIndex = round(linspace(1,size(allParameters,1),N)');
        for i = 1:nParameters
            [~,sortIndex] = sort(allParameters(:,i+1));
            sortedParameters = allParameters(sortIndex,2:end-1);
            sampleParameters((i*N)-(N-1):i*N,:) = sortedParameters(rowIndex,:);
        end

        [~,optimalIndex] = min(allParameters(:,1));
        optimalParameters = allParameters(optimalIndex,2:end-1);

        sampleParameters = [optimalParameters;sampleParameters(2:end,:)]; % add the optimalparameters at the top of the sample parameters matrix


        %% Method 5 - Get all paramaeters
    case 5
        sampleParameters = sortrows(allParameters); %  sort the parameters according to the fval columm
        sampleParameters = sampleParameters(:,2:end-1);
end

end

